@@ -1,4 +1,7 @@
+# coding: utf8
+
 import json
+import re
 
 class Entity():
     """docstring for Entity"""
@@ -49,12 +52,12 @@ class Intent():
     the API.AI develoepr console via JSON requests.
     """
 
-    def __init__(self, name=None, priority=500000, fallback_intent=False, intent_json=None):
+    def __init__(self, name=None, priority=500000, fallback_intent=False, contexts=None, events=None, intent_json=None):
 
         if name and not intent_json:
             self.name = name
             self.auto = True
-            self.contexts = []
+            self.contexts = contexts or []
             self.templates = []
             self.userSays = []
             self.responses = []
@@ -62,7 +65,7 @@ class Intent():
             self.fallbackIntent = fallback_intent
             self.webhookUsed = True
             self.webhookForSlotFilling = True
-            self.events = []
+            self.events = Intent._build_events(events)
             self.id = None
 
         elif intent_json:
@@ -71,6 +74,10 @@ class Intent():
         else:
             raise TypeError('Must provide a "name" argument if no json given')
 
+    @staticmethod
+    def _build_events(events):
+        return [] if events is None else [{'name': event} for event in events]
+
     def __repr__(self):
         return "<Intent: {}>".format(self.name)
 
@@ -96,6 +103,9 @@ class Intent():
             'messages': []  # TODO: possibly register action responses to call from intent object directly
         }]
         # self.responses.append(new_response)
+    
+    def add_event(self, event_name):
+        self.events.append({'name': event_name})
 
     @property
     def serialize(self):
@@ -143,26 +153,24 @@ class UserDefinedExample(ExampleBase):
         # import ipdb; ipdb.set_trace()
         self.entity_map = entity_map
 
-        self.parse_phrase()
+        self._parse_phrase(self.text)
 
-    def parse_phrase(self):
-        # import ipdb; ipdb.set_trace()
-        annotated = {}
-        sub_phrase = ''
+    def _parse_phrase(self, sub_phrase):
+        if not sub_phrase:
+            return
 
-        for word in self.text.split():
-            if word in self.entity_map:
-                self.data.append({'text': sub_phrase})  # add non-annotated, then deal with annotation
-                sub_phrase = ''
-                self.annotate_params(word)
+        for value in self.entity_map:
+            re_value = r".\b{}\b".format(value[1:]) if value.startswith(('$', '¥', '￥', '€', '£')) else r"\b{}\b".format(value)
+            if re.search(re_value, sub_phrase):
+                parts = sub_phrase.split(value, 1)
+                self._parse_phrase(parts[0])
+                self._annotate_params(value)
+                self._parse_phrase(parts[1])
+                return
 
-            else:
-                sub_phrase += '{} '.format(word)
+        self.data.append({'text': sub_phrase})
 
-        if sub_phrase:
-            self.data.append({'text': sub_phrase})
-
-    def annotate_params(self, word):
+    def _annotate_params(self, word):
         """Annotates a given word for the UserSays data field of an Intent object.
 
         Annotations are created using the entity map within the user_says.yaml template.
